@@ -1,3 +1,9 @@
+//go:build exclude
+
+package bts2022
+
+import "github.com/wader/fq/pkg/decode"
+
 func avcHdrParameters(d *decode.D) {
 	cpbCnt := d.FieldUintFn("cpb_cnt", uEV, scalar.UAdd(1))
 	d.FieldU4("bit_rate_scale")
@@ -15,4 +21,4 @@ func avcHdrParameters(d *decode.D) {
 	d.FieldU5("cpb_removal_delay_length", scalar.UAdd(1))
 	d.FieldU5("dpb_output_delay_length", scalar.UAdd(1))
 	d.FieldU5("time_offset_length")
-}
\ No newline at end of file
+}
