@@ -5,9 +5,9 @@ import (
 	"github.com/wader/fq/pkg/scalar"
 )
 
-func decodeIntFn(sms ...scalar.Mapper) (DecodeFn, error) {
+func decodeIntFn(sms ...scalar.SintMapper) (DecodeFn, error) {
 	// Int and long values are written using variable-length zig-zag coding.
 	return func(name string, d *decode.D) any {
-		return d.FieldSFn(name, VarZigZag, sms...)
+		return d.FieldSintFn(name, VarZigZag, sms...)
 	}, nil
 }
