@@ -8,12 +8,13 @@ import (
 )
 
 func init() {
-	interp.RegisterFormat(decode.Format{
-		Name:        format.ICMP,
-		Description: "Internet Control Message Protocol",
-		Groups:      []string{format.IP_PACKET},
-		DecodeFn:    decodeICMP,
-	})
+	interp.RegisterFormat(
+		format.ICMP,
+		&decode.Format{
+			Description: "Internet Control Message Protocol",
+			Groups:      []*decode.Group{format.IP_Packet},
+			DecodeFn:    decodeICMP,
+		})
 }
 
 // based on https://en.wikipedia.org/wiki/Internet_Control_Message_Protocol
@@ -93,7 +94,7 @@ var icmpCodeMapMap = map[uint64]scalar.UintMapDescription{
 }
 
 func decodeICMP(d *decode.D) any {
-	var ipi format.IPPacketIn
+	var ipi format.IP_Packet_In
 	if d.ArgAs(&ipi) && ipi.Protocol != format.IPv4ProtocolICMP {
 		d.Fatalf("incorrect protocol %d", ipi.Protocol)
 	}
