@@ -136,20 +136,21 @@ type stsz struct {
 }
 
 type track struct {
-	seenHdlr           bool
-	fragment           bool
-	id                 int
-	sampleDescriptions []sampleDescription
-	subType            string
-	stco               []int64
-	stsc               []stsc
-	stsz               []stsz
-	formatInArg        any
-	objectType         int // if data format is "mp4a"
-	defaultIVSize      int
-	moofs              []*moof // for fmp4
-	dref               bool
-	drefURL            string
+	seenHdlr             bool
+	fragment             bool
+	id                   int
+	sampleDescriptions   []sampleDescription
+	subType              string
+	stco                 []int64
+	stsc                 []stsc
+	stsz                 []stsz
+	formatInArg          any
+	objectType           int // if data format is "mp4a"
+	defaultIVSize        int
+	moofs                []*moof // for fmp4
+	dref                 bool
+	drefURL              string
+	stsdNumAudioChannels uint64
 }
 
 type pathEntry struct {
@@ -320,6 +321,7 @@ func mp4Tracks(d *decode.D, ctx *decodeContext) {
 
 				switch trackSDDataFormat {
 				case "lpcm",
+					"ipcm",
 					"raw ",
 					"twos",
 					"sowt",
@@ -334,6 +336,10 @@ func mp4Tracks(d *decode.D, ctx *decodeContext) {
 					return
 				}
 
+				if ctx.opts.SkipSamples {
+					return
+				}
+
 				d.FieldArray("samples", func(d *decode.D) {
 					// TODO: warning? could also be init fragment etc
 
