@@ -80,17 +80,17 @@ func avcPPSDecode(d *decode.D) any {
 		picScalingMatrixPresentFlag := d.FieldBool("pic_scaling_matrix_present_flag")
 		if picScalingMatrixPresentFlag {
 			d.FieldArray("pic_scaling_list", func(d *decode.D) {
-				for i := 0; i < 6; i++ {
+				for range 6 {
 					d.Bool()
 				}
 			})
 		}
 		d.FieldSintFn("second_chroma_qp_index_offset", sEV)
 	} else {
-		d.FieldBool("rbsp_stop_one_bit")
+		d.FieldBool("stop_one_bit")
 	}
 
-	d.FieldRawLen("rbsp_trailing_bits", d.BitsLeft())
+	d.FieldRawLen("trailing_bits", d.BitsLeft())
 
 	return nil
 }
