@@ -3,7 +3,7 @@ package interp
 import (
 	"math/big"
 
-	"github.com/wader/fq/internal/gojqex"
+	"github.com/wader/fq/internal/gojqx"
 	"github.com/wader/gojq"
 )
 
@@ -25,7 +25,7 @@ func (i *Interp) bnot(c any) any {
 	case gojq.JQValue:
 		return i.bnot(c.JQValueToGoJQ())
 	default:
-		return &gojqex.UnaryTypeError{Name: "bnot", V: c}
+		return &gojqx.UnaryTypeError{Name: "bnot", V: c}
 	}
 }
 
@@ -39,12 +39,12 @@ func (i *Interp) bsl(c any, a any, b any) any {
 		},
 		func(l, r float64) any { return int(l) << int(r) },
 		func(l, r *big.Int) any { return new(big.Int).Lsh(l, uint(r.Uint64())) },
-		func(l, r string) any { return &gojqex.BinopTypeError{Name: "bsl", L: l, R: r} },
-		func(l, r []any) any { return &gojqex.BinopTypeError{Name: "bsl", L: l, R: r} },
+		func(l, r string) any { return &gojqx.BinopTypeError{Name: "bsl", L: l, R: r} },
+		func(l, r []any) any { return &gojqx.BinopTypeError{Name: "bsl", L: l, R: r} },
 		func(l, r map[string]any) any {
-			return &gojqex.BinopTypeError{Name: "bsl", L: l, R: r}
+			return &gojqx.BinopTypeError{Name: "bsl", L: l, R: r}
 		},
-		func(l, r any) any { return &gojqex.BinopTypeError{Name: "bsl", L: l, R: r} },
+		func(l, r any) any { return &gojqx.BinopTypeError{Name: "bsl", L: l, R: r} },
 	)
 }
 
@@ -53,12 +53,12 @@ func (i *Interp) bsr(c any, a any, b any) any {
 		func(l, r int) any { return l >> r },
 		func(l, r float64) any { return int(l) >> int(r) },
 		func(l, r *big.Int) any { return new(big.Int).Rsh(l, uint(r.Uint64())) },
-		func(l, r string) any { return &gojqex.BinopTypeError{Name: "bsr", L: l, R: r} },
-		func(l, r []any) any { return &gojqex.BinopTypeError{Name: "bsr", L: l, R: r} },
+		func(l, r string) any { return &gojqx.BinopTypeError{Name: "bsr", L: l, R: r} },
+		func(l, r []any) any { return &gojqx.BinopTypeError{Name: "bsr", L: l, R: r} },
 		func(l, r map[string]any) any {
-			return &gojqex.BinopTypeError{Name: "bsr", L: l, R: r}
+			return &gojqx.BinopTypeError{Name: "bsr", L: l, R: r}
 		},
-		func(l, r any) any { return &gojqex.BinopTypeError{Name: "bsr", L: l, R: r} },
+		func(l, r any) any { return &gojqx.BinopTypeError{Name: "bsr", L: l, R: r} },
 	)
 }
 
@@ -67,12 +67,12 @@ func (i *Interp) band(c any, a any, b any) any {
 		func(l, r int) any { return l & r },
 		func(l, r float64) any { return int(l) & int(r) },
 		func(l, r *big.Int) any { return new(big.Int).And(l, r) },
-		func(l, r string) any { return &gojqex.BinopTypeError{Name: "band", L: l, R: r} },
-		func(l, r []any) any { return &gojqex.BinopTypeError{Name: "band", L: l, R: r} },
+		func(l, r string) any { return &gojqx.BinopTypeError{Name: "band", L: l, R: r} },
+		func(l, r []any) any { return &gojqx.BinopTypeError{Name: "band", L: l, R: r} },
 		func(l, r map[string]any) any {
-			return &gojqex.BinopTypeError{Name: "band", L: l, R: r}
+			return &gojqx.BinopTypeError{Name: "band", L: l, R: r}
 		},
-		func(l, r any) any { return &gojqex.BinopTypeError{Name: "band", L: l, R: r} },
+		func(l, r any) any { return &gojqx.BinopTypeError{Name: "band", L: l, R: r} },
 	)
 }
 
@@ -81,12 +81,12 @@ func (i *Interp) bor(c any, a any, b any) any {
 		func(l, r int) any { return l | r },
 		func(l, r float64) any { return int(l) | int(r) },
 		func(l, r *big.Int) any { return new(big.Int).Or(l, r) },
-		func(l, r string) any { return &gojqex.BinopTypeError{Name: "bor", L: l, R: r} },
-		func(l, r []any) any { return &gojqex.BinopTypeError{Name: "bor", L: l, R: r} },
+		func(l, r string) any { return &gojqx.BinopTypeError{Name: "bor", L: l, R: r} },
+		func(l, r []any) any { return &gojqx.BinopTypeError{Name: "bor", L: l, R: r} },
 		func(l, r map[string]any) any {
-			return &gojqex.BinopTypeError{Name: "bor", L: l, R: r}
+			return &gojqx.BinopTypeError{Name: "bor", L: l, R: r}
 		},
-		func(l, r any) any { return &gojqex.BinopTypeError{Name: "bor", L: l, R: r} },
+		func(l, r any) any { return &gojqx.BinopTypeError{Name: "bor", L: l, R: r} },
 	)
 }
 
@@ -95,11 +95,11 @@ func (i *Interp) bxor(c any, a any, b any) any {
 		func(l, r int) any { return l ^ r },
 		func(l, r float64) any { return int(l) ^ int(r) },
 		func(l, r *big.Int) any { return new(big.Int).Xor(l, r) },
-		func(l, r string) any { return &gojqex.BinopTypeError{Name: "bxor", L: l, R: r} },
-		func(l, r []any) any { return &gojqex.BinopTypeError{Name: "bxor", L: l, R: r} },
+		func(l, r string) any { return &gojqx.BinopTypeError{Name: "bxor", L: l, R: r} },
+		func(l, r []any) any { return &gojqx.BinopTypeError{Name: "bxor", L: l, R: r} },
 		func(l, r map[string]any) any {
-			return &gojqex.BinopTypeError{Name: "bxor", L: l, R: r}
+			return &gojqx.BinopTypeError{Name: "bxor", L: l, R: r}
 		},
-		func(l, r any) any { return &gojqex.BinopTypeError{Name: "bxor", L: l, R: r} },
+		func(l, r any) any { return &gojqx.BinopTypeError{Name: "bxor", L: l, R: r} },
 	)
 }
