@@ -27,6 +27,13 @@ func TestRangeGaps(t *testing.T) {
 		{"0:10", "1:1 2:5 8:1", "0:1 9:1"},
 		{"0:10", "1:1 2:8 8:2", "0:1"},
 		{"0:10", "0:4 2:8 8:2", ""},
+
+		// handle empty ranges
+		{"0:12", "4:4 8:0", "0:4 8:4"},
+		{"0:12", "0:0 4:4", "0:4 8:4"},
+		{"0:12", "0:0 4:4 8:0", "0:4 8:4"},
+		{"0:12", "0:0 0:0 4:4 8:0 8:0", "0:4 8:4"},
+		{"0:12", "8:0", "0:12"},
 	}
 	for _, tC := range testCases {
 		t.Run(fmt.Sprintf("%v_%v_%v", tC.total, tC.ranges, tC.expected), func(t *testing.T) {
